==> delphixpy-1.11.20.0.tar.gz: delphixpy-1.11.20.0/delphixpy/v1_11_18/web/__init__.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "web"
"""
from . import transformation
from . import action
from . import passwordPolicy
from . import notification
from . import sourceconfig
from . import authorization
from . import about
from . import source
from . import registration
from . import toolkit
from . import fault
from . import user
from . import repository
from . import namespace
from . import role
from . import host
from . import storage
from . import connectivity
from . import maskingjob
from . import session
from . import selfservice
from . import service
from . import policy
from . import job
from . import timeflow
from . import data
from . import permission
from . import snapshot
from . import alert
from . import objects
from . import replication
from . import environment
from . import repave
from . import delphix
from . import usage
from . import license
from . import analytics
from . import system
from . import network
from . import database
from . import timezone
from . import domain
from . import osadmin
from . import theme
from . import group
from . import capacity

==> delphixpy-1.11.26.0.tar.gz: delphixpy-1.11.26.0/delphixpy/v1_9_2/web/__init__.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "web"
"""
from . import authorization
from . import permission
from . import passwordPolicy
from . import role
from . import toolkit
from . import environment
from . import capacity
from . import database
from . import registration
from . import host
from . import data
from . import transformation
from . import repository
from . import policy
from . import user
from . import alert
from . import objects
from . import maskingjob
from . import timezone
from . import fault
from . import group
from . import connectivity
from . import notification
from . import insight
from . import delphix
from . import job
from . import about
from . import timeflow
from . import action
from . import storage
from . import domain
from . import analytics
from . import selfservice
from . import snapshot
from . import sourceconfig
from . import namespace
from . import replication
from . import source
from . import service
from . import system
from . import network
from . import session
